@@ -74,6 +74,7 @@ function endsWith(str, end) {
 var PersonaService = {
     THUNDERBIRD_ID: "{3550f703-e582-4d05-9a08-453d09bdfdc6}",
     FIREFOX_ID: "{ec8030f7-c20a-464f-9b0e-13a3a9e97384}",
+    SEAMONKEY_ID:"{92650c4d-4b8e-4d2a-b7eb-24ecf4f6b63a}",
 
     // Wraps event listener functions so errors are not lost.
     wrap: function(fn) {
@@ -136,12 +137,6 @@ var PersonaService = {
 
         // Observe quit so we can destroy ourselves.
         Observers.add("quit-application", this.onQuitApplication, this);
-        // Observe the "cookie-changed" topic to load the favorite personas when
-        // the user signs in.
-        if (false)
-        // Skip this for now, since AMO session cookies are not currently
-        // cooperative
-            Observers.add("cookie-changed", this.onCookieChanged, this);
         // Observe the "lightweight-theme-changed" to sync the add-on with the
         // lightweight theme manager.
         Observers.add("lightweight-theme-changed",
@@ -150,8 +145,6 @@ var PersonaService = {
         Observers.add("http-on-examine-response",
             this.onHTTPResponse, this);
 
-        this._prefs.observe("useTextColor", this.onUseColorChanged, this);
-        this._prefs.observe("useAccentColor", this.onUseColorChanged, this);
         this._prefs.observe("selected", this.onSelectedModeChanged, this);
         this._prefs.observe("addons-host", this.onAddonsHostChanged, this);
 
@@ -253,13 +246,10 @@ var PersonaService = {
     },
 
     _destroy: function() {
-        Observers.remove("cookie-changed", this.onCookieChanged, this);
         Observers.remove("lightweight-theme-changed",
             this.onLightweightThemeChanged, this);
         Observers.remove("http-on-examine-response", this.onHTTPResponse, this);
 
-        this._prefs.ignore("useTextColor", this.onUseColorChanged, this);
-        this._prefs.ignore("useAccentColor", this.onUseColorChanged, this);
         this._prefs.ignore("selected", this.onSelectedModeChanged, this);
         this._prefs.ignore("addons-host", this.onAddonsHostChanged, this);
     },
@@ -460,7 +450,7 @@ var PersonaService = {
 
         try {
             var json = JSON.parse(request.responseText)
-                .addons.filter(function(a) a.theme);
+                .addons.filter( a => a.theme);
         } catch (ex) {
             this._log.debug("error parsing favorites data: " + request.responseText.slice(0, 100) + "...");
             return;
@@ -608,7 +598,7 @@ var PersonaService = {
     // The JSON feed of favorite personas retrieved from the server.
     _favorites: null,
 
-    get favorites() this._favorites,
+    get favorites() {return this._favorites;},
     set favorites(val) {
         this._favorites = val;
 
@@ -621,7 +611,7 @@ var PersonaService = {
             FileUtils.writeFile(path, "favorites.json", JSON.stringify(val));
         else {
             path.append("favorites.json");
-            OS.File.remove(path.spec);
+            if(path.exists()) OS.File.remove(path.spec);
         }
     },
 
@@ -741,9 +731,26 @@ var PersonaService = {
     changeToRandomPersona: function(category) {
         this.category = category;
         this.currentPersona = this._getRandomPersonaFromCategory(category);
+        this._addPersonaToRecent(this.currentPersona);
         this.selected = "random";
         this._prefs.set("persona.lastChanged", new Date().getTime().toString());
         this._notifyPersonaChanged(this.currentPersona);
+
+        let persona = this.currentPersona;
+        // Check whether the persona is in the favorites or the recent lists,
+        // in which case the change-notification should not be shown.
+        let recent = this.getRecentPersonas();
+        let favorites = this.favorites;
+        let inRecent = (recent && recent.some(v => v.id == persona.id));
+        let inFavorites = (favorites && favorites.some(v => v.id == persona.id));
+
+        // Show the notification if the selected persona is not in the favorite or
+        // recent lists, is not a custom persona and its author or username is not null.
+        // In this case we make sure at least one of these two fields is not null
+        // to prevent bug 526788.
+        if (!inRecent && !inFavorites && !persona.custom && (persona.author || persona.username))
+            this._showPersonaChangeNotification();
+
     },
 
     changeToRandomFavoritePersona: function() {
@@ -768,9 +775,9 @@ var PersonaService = {
         let recent = this.getRecentPersonas();
         let favorites = this.favorites;
         let inRecent =
-            (recent && recent.some(function(v) v.id == persona.id));
+            (recent && recent.some( v => v.id == persona.id));
         let inFavorites =
-            (favorites && favorites.some(function(v) v.id == persona.id));
+            (favorites && favorites.some( v => v.id == persona.id));
 
         this.currentPersona = persona;
         this._addPersonaToRecent(persona);
@@ -827,6 +834,9 @@ var PersonaService = {
             } else
                 this.resetPersona();
         }
+        else{
+            this.changeToDefaultPersona();
+        }
     },
 
     /**
@@ -957,7 +967,7 @@ var PersonaService = {
         // to appear twice on the list).  Afterwards, we'll add the recent persona
         // to the list in a way that makes it the most recent one.
         if (persona.id)
-            personas = personas.filter(function(v) !v.id || v.id != persona.id);
+            personas = personas.filter( v => !v.id || v.id != persona.id);
 
         // Make the new persona the most recent one.
         personas.unshift(persona);
@@ -996,14 +1006,6 @@ var PersonaService = {
         }
     },
 
-    onUseColorChanged: function() {
-        // Notify observers that the persona has changed so the change in whether
-        // or not to use the text or accent color will get applied.  The persona
-        // hasn't really changed, but doing this has the desired effect without any
-        // known unwanted side effects.
-        Observers.notify("personas:persona:changed");
-    },
-
     previewingPersona: null,
 
     /**
@@ -1054,7 +1056,7 @@ var PersonaService = {
             let cookieHost = cookie.host.replace(/^\./, "");
 
             if (cookie.name == COOKIE_INITIAL_PERSONA &&
-                authorizedHosts.some(function(v) v == cookieHost)) {
+                authorizedHosts.some( v => v == cookieHost)) {
 
                 // There could be more than one "initial_persona" cookie. The cookie
                 // with latest expiration time is selected.
@@ -1330,27 +1332,6 @@ var PersonaService = {
         return null;
     },
 
-    /**
-     * Monitors changes in cookies. If the modified cookie is the Personas session
-     * cookie, then the favorites are refreshed (if the user is signed in).
-     * @param aCookie The cookie that has been added, changed or removed.
-     */
-    onCookieChanged: function(aCookie, aChange) {
-        if (aCookie instanceof Ci.nsICookie) {
-            if (aCookie.name == "sessionid" && (aCookie.host == this.addonsHost ||
-                    aCookie.host == "." + this.addonsHost)) {
-                if (aCookie.value == this._cookieValue)
-                    return;
-                this._cookieValue = aCookie.value;
-                this.refreshFavorites();
-            }
-        } else if (aCookie instanceof Ci.nsIArray) {
-            for (let enum_ = aCookie.enumerate(); enum_.hasMoreElements();)
-                this.onCookieChanged(enum_.getNext());
-        }
-    },
-    _cookieValue: null,
-
     /**
      * Monitors HTTP responses so that we can heuristically detect logins
      * and logouts.
@@ -1363,7 +1344,7 @@ var PersonaService = {
         if (uri.host != this.addonsHost)
             return;
 
-        if (endsWith(uri.filePath, "/users/logout") || aRequest.requestMethod == "POST" && endsWith(uri.filePath, "/users/login"))
+        if (endsWith(uri.filePath, "/users/logout") || aRequest.requestMethod == "POST" && endsWith(uri.filePath, "/users/login") || endsWith(uri.filePath, "/api/v3/accounts/authenticate/"))
             this.refreshFavorites();
     },
 
@@ -1461,7 +1442,7 @@ var FileUtils = {
             if (!dir.exists() || !dir.isDirectory()) {
                 if (!aDontCreate) {
                     // read and write permissions to owner and group, read-only for others.
-                    dir.create(Ci.nsIFile.DIRECTORY_TYPE, 0774);
+                    dir.create(Ci.nsIFile.DIRECTORY_TYPE, 0o774);
                 }
             }
         } catch (ex) {
